var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><script src=\"../scripts/lib/jquery-1.11.1.min.js\" type=\"text/javascript\"></script><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Executing Python from MAXScript</title>\n\
   <meta name=\"topic-subtype\" content=\"Python\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style><script>$(document).ready(function() { yepnope.injectJs(\"./scripts/multireflink.js\"); });</script><script></script><div id=\"reflinkdiv\"></div>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Executing Python from MAXScript</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"executing-python-from-maxscript\"></a></div>\n\
<div class=\'section\'><a id=\"using-python-libraries-in-maxscript\"></a><h2 id=\"using-python-libraries-in-maxscript\">Using Python Libraries in MAXScript</h2></div>\n\
<p>Python libraries can be imported and used in MAXScript, using <span class=\'code\'>Python.Import()</span>. In this example, we import the Python built-in methods and constants, and use the <span class=\'code\'>pow()</span> function:</p>\n\
<div class=\'codeBlock\'><pre>bi = Python.Import &quot;__builtin__&quot;\n\
-- &lt;module &#39;__builtin__&#39; (built-in)&gt;\n\
bi.pow 2 3\n\
-- 8  \n\
</pre></div><p>If a module gets dirty (for example, a keyword gets re-defined), you can re-import using <span class=\'code\'>Python.Reload()</span>:</p>\n\
<div class=\'codeBlock\'><pre>python.reload bi\n\
-- &lt;module &#39;__builtin__&#39; (built-in)&gt;\n\
</pre></div><p>Simple Python types, such as int, bool, float, and str, are copied into their corresponding MAXScript types. Complex types, such as lists, tuples, dictionaries and classes, are marshalled through a wrapper object. The properties and functions of the type are accessible by name. For sequence types such as a list, you can iterate using the index. Python lists passed to MAXScript are 1-based.</p>\n\
<p>For example, to create and access a Python tuple:</p>\n\
<div class=\'codeBlock\'><pre>bi = python.import(&quot;__builtin__&quot;)\n\
tp = bi.Tuple(#(1,2,3)) --(1, 2, 3)\n\
print tp[0] -- output: 1\n\
bi.type(tp) -- output: &lt;type &#39;tuple&#39;&gt;\n\
</pre></div><p>And to create and access a Python dict:</p>\n\
<div class=\'codeBlock\'><pre>d = bi.dict one:1 two:2 three:3 -- {u&#39;one&#39;: 1, u&#39;three&#39;: 3, u&#39;two&#39;: 2}\n\
d[&quot;four&quot;] = 4\n\
bi.print(d[&quot;four&quot;]) -- 4\n\
</pre></div><p>Here is an example of 1-based list passed to back to MAXScript from Python:</p>\n\
<div class=\'codeBlock\'><pre>str = python.import(&quot;string&quot;)\n\
mystrlist = str.split(&quot;an example string&quot;)\n\
mystrlist[1]\n\
-- prints &quot;an&quot;\n\
</pre></div><div class=\'section\'><a id=\"limitations\"></a><h3 id=\"limitations\">Limitations</h3></div>\n\
<p>Because of the way Python is wrapped in MAXScript, methods and functions bound to Python execution frames will not work as expected, if at all. Some examples of calls that will not work via <span class=\'code\'>Python.import()</span> include:</p>\n\
<ul>\n\
<li><span class=\'code\'>sys._current_frames</span></li>\n\
<li><span class=\'code\'>sys._get_frame</span></li>\n\
<li><span class=\'code\'>module.globals()</span></li>\n\
<li><span class=\'code\'>module.locals()</span></li>\n\
</ul>\n\
<div class=\'section\'><a id=\"executing-python-from-maxscript-1\"></a><h2 id=\"executing-python-from-maxscript-1\">Executing Python from MAXScript</h2></div>\n\
<p>You can execute Python commands and statements (can be a single command/expression or a series of statements); or a Python script (for example, a <span class=\'code\'>.py</span> script) from within MAXScript. Use the <span class=\'code\'>python.Execute</span> and <span class=\'code\'>python.ExecuteFile</span> commands respectively, as follows:</p>\n\
<div class=\'codeBlock\'><pre>python.Execute &quot;print &#39;hello&#39;&quot;\n\
\n\
python.ExecuteFile &quot;demoBentCylinder.py&quot;\n\
</pre></div><p>If you provide a full path using the <span class=\'code\'>ExecuteFile</span> command; for example, as follows; 3ds Max looks for the Python file in the path provided.</p>\n\
<div class=\'codeBlock\'><pre>python.ExecuteFile @&quot;C:\\Program Files\\Autodesk\\3ds Max 2015\\scripts\\Python\\demoBentCylinder.py&quot;\n\
</pre></div><p>Otherwise, 3ds Max looks for the Python script under the following directories:</p>\n\
<ul>\n\
<li>User Scripts directory</li>\n\
<li>User Startup Scripts directory</li>\n\
<li>Scripts directory</li>\n\
<li>Startup Scripts</li>\n\
<li>Windows paths specified by the <span class=\'code\'>Path</span> environment variable. To see a list of these directories, enter <span class=\'code\'>echo %path%</span> in your command prompt.</li>\n\
</ul>\n\
<p>For example, 3ds Max would search under the following directories: <span class=\'code\'>userscripts\\\\python</span>, <span class=\'code\'>userscripts\\\\startup\\\\python</span>, <span class=\'code\'>scripts\\\\python</span>, <span class=\'code\'>scripts\\\\startup\\\\python</span>, and subsequently the windows paths.</p>\n\
<p>The output of the results from scripts are printed to the MAXScript Listener window.</p>\n\
<p><strong>Note</strong> Python scripts run in MAXScript are not thread-safe. Python commands are always executed in the main 3ds Max thread. You should not attempt to spawn separate threads in your scripts (for example, by using the Python threading module).</p>\n\
<div class=\'section\'><a id=\"python-interface-methods\"></a><h2 id=\"python-interface-methods\">Python interface methods</h2></div>\n\
<p>The MAXScript Python interface contains methods for using Python in MAXScript. If you run</p>\n\
<div class=\'codeBlock\'><pre>showinterface python\n\
</pre></div><p>in MAXScript, you obtain, in the MAXScript Listener, a list of available methods. The following list describes these methods and arguments:</p>\n\
<ul>\n\
<li><span class=\'code\'>Init()</span>: Loads Python if it is not loaded already.</li>\n\
<li><span class=\'code\'>Execute()</span> and <span class=\'code\'>ExecuteFile()</span>: Loads Python if it is not loaded already. Use <span class=\'code\'>Init()</span> if you know that you will be using Python, and do not want the delay associated with loading it to occur the first time it is used. You would call <span class=\'code\'>python.Init()</span> in a startup script to take the load time hit at startup, rather than while actually using 3ds Max.</li>\n\
<li><span class=\'code\'>Import()</span>: Imports a Python module.</li>\n\
<li><span class=\'code\'>Reload()</span>: Reloads a Python module, for example if it has been re-defined.</li>\n\
<li><p><span class=\'code\'>GetLastError()</span>: Returns, as a string, the error message associated with the last error encountered while running the <span class=\'code\'>Init()</span>, <span class=\'code\'>Execute()</span>, or <span class=\'code\'>ExecuteFile()</span> methods.</p></li>\n\
<li>Result codes (<span class=\'code\'>enums</span>): When executing Python from MAXScript, the result codes can be the following constants:\n\
<ul>\n\
<li><span class=\'code\'>\\#success</span></li>\n\
<li><span class=\'code\'>\\#pathError</span></li>\n\
<li><span class=\'code\'>\\#initError</span></li>\n\
<li><span class=\'code\'>\\#scriptFileError</span></li>\n\
<li><span class=\'code\'>\\#executeError</span></li>\n\
</ul></li>\n\
<li><p><span class=\'code\'>throwOnError</span> keyword argument: Controls whether MAXScript throws a runtime exception if an error occurs while running a method. If set to <span class=\'code\'>true</span>, you always obtain a return result code of <span class=\'code\'>\\#success</span> because, in all other cases, a runtime exception would be thrown. It would be up to the script writer to make the call within a try/catch in order to handle the exception.</p></li>\n\
</ul>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";