var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><script src=\"../../scripts/lib/jquery-1.11.1.min.js\" type=\"text/javascript\"></script><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Creating a bitmap</title>\n\
   <meta name=\"topic-subtype\" content=\"Python\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style><script>$(document).ready(function() { yepnope.injectJs(\"./scripts/multireflink.js\"); });</script><script></script><div id=\"reflinkdiv\"></div>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Creating a bitmap</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"creating-a-bitmap\"></a></div>\n\
<div class=\'section\'><a id=\"example\"></a><h2 id=\"example\">Example</h2></div>\n\
<p>The following example demonstrates how to create a bitmap:</p>\n\
<div class=\'codeBlock\'><pre>import MaxPlus\n\
\n\
# Bitmap Types\n\
class BitmapTypes(object):\n\
    BMM_NO_TYPE  = 0  # Not allocated yet\n\
    BMM_LINE_ART = 1  # 1-bit monochrome image\n\
    BMM_PALETTED = 2  # 8-bit paletted image. Each pixel value is an index into the color table.\n\
    BMM_GRAY_8   = 3  # 8-bit grayscale bitmap.\n\
    BMM_GRAY_16  = 4  # 16-bit grayscale bitmap.\n\
    BMM_TRUE_16  = 5  # 16-bit true color image.\n\
    BMM_TRUE_32  = 6  # 32-bit color: 8 bits each for Red, Green, Blue, and Alpha.\n\
    BMM_TRUE_64  = 7  # 64-bit color: 16 bits each for Red, Green, Blue, and Alpha.\n\
    BMM_TRUE_24  = 8  # 24-bit color: 8 bits each for Red, Green, and Blue. Cannot be written to.\n\
    BMM_TRUE_48  = 9  # 48-bit color: 16 bits each for Red, Green, and Blue. Cannot be written to.\n\
    BMM_YUV_422  = 10 # This is the YUV format - CCIR 601. Cannot be written to.\n\
    BMM_BMP_4    = 11 # Windows BMP 16-bit color bitmap.  Cannot be written to.\n\
    BMM_PAD_24   = 12 # Padded 24-bit (in a 32 bit register).  Cannot be written to.\n\
    BMM_LOGLUV_32 = 13\n\
    BMM_LOGLUV_24 = 14\n\
    BMM_LOGLUV_24A    = 15\n\
    BMM_REALPIX_32    = 16 # The &#39;Real Pixel&#39; format.\n\
    BMM_FLOAT_RGBA_32 = 17 # 32-bit floating-point per component (non-compressed), RGB with or without alpha\n\
    BMM_FLOAT_GRAY_32 = 18 # 32-bit floating-point (non-compressed), monochrome/grayscale\n\
    BMM_FLOAT_RGB_32 = 19\n\
    BMM_FLOAT_A_32 = 20\n\
\n\
\n\
def CreateABitmap():\n\
    # This is one way to create a bitmap\n\
    foo = <a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Factory.CreateBitmap\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_factory.html#a07ee5f23ef113ffd43794d70546ba7c2&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MaxPlus.Factory.CreateBitmap</a>()\n\
    print &#39;Bitmap:&#39;, foo\n\
    \n\
    # First allocate some storage. This is where the type of bitmap is determined. \n\
    # (see class BitmapTypes above)\n\
    storage = <a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Factory.CreateStorage\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_factory.html#af4f1df3ba6f8da558b15dc4ede6e9491&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MaxPlus.Factory.CreateStorage</a>(BitmapTypes.BMM_TRUE_32)\n\
    print &#39;BitmapStorage:&#39;, storage\n\
    \n\
    # Now we can get the bitmap info\n\
    info = storage.GetBitmapInfo()\n\
    print &#39;Bitmap Information:&#39;, info\n\
    \n\
    # Set some common properties on the bitmap\n\
    info.SetWidth(720)\n\
    info.SetHeight(620)\n\
    info.SetName(&#39;My demonstration bitmap&#39;)\n\
    info.SetGamma(2.2)\n\
    \n\
    # Verify a few things\n\
    assert(storage.GetWidth() == 720)\n\
    assert(storage.GetHeight() == 620)\n\
    print info.GetName()\n\
\n\
    # Allocate storage for writing to the bitmap\n\
    storage.Allocate(info, 2)\n\
    \n\
    for x in range(720):\n\
        for y in range(620):\n\
            storage.PutPixel(x,y,(<a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Color64\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_color64.html&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MaxPlus.Color64</a>(64000-(x*(64000/720)),(y*(64000/720)),64000,64000)))\n\
    \n\
    foo.SetStorage(storage)\n\
\n\
    foo.Display()\n\
\n\
CreateABitmap()\n\
</pre></div><div class=\'section\'><a id=\"creating-a-bitmap-1\"></a><h2 id=\"creating-a-bitmap-1\">Creating a bitmap</h2></div>\n\
<p>To create a bitmap, call <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"Factory.CreateBitmap()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_factory.html#a07ee5f23ef113ffd43794d70546ba7c2&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">Factory.CreateBitmap()</a></span>.</p>\n\
<div class=\'codeBlock\'><pre>foo = <a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Factory.CreateBitmap\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_factory.html#a07ee5f23ef113ffd43794d70546ba7c2&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MaxPlus.Factory.CreateBitmap</a>()\n\
</pre></div><p>You must also allocate storage for the bitmap by calling <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"Factory.CreateStorage()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_factory.html#af4f1df3ba6f8da558b15dc4ede6e9491&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">Factory.CreateStorage()</a></span>. This method takes an integer as input; therefore, the class <span class=\'code\'>BitmapTypes</span> was created to define available bitmap types and their corresponding integer values that can be passed to <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"Factory.CreateStorage()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_factory.html#af4f1df3ba6f8da558b15dc4ede6e9491&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">Factory.CreateStorage()</a></span>. An object of class <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"BitmapStorage\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap_storage.html&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">BitmapStorage</a></span> is created.</p>\n\
<div class=\'codeBlock\'><pre>storage = <a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Factory.CreateStorage\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_factory.html#af4f1df3ba6f8da558b15dc4ede6e9491&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MaxPlus.Factory.CreateStorage</a>(BitmapTypes.BMM_TRUE_32)\n\
</pre></div><p><span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"BitmapStorage.GetBitmapInfo()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap_storage.html#a252189f4d827f9a68fb0342958afc625&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">BitmapStorage.GetBitmapInfo()</a></span> returns an object of class <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"BitmapInfo\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap_info.html&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">BitmapInfo</a></span> and you can then call the <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"BitmapInfo.SetWidth()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap_info.html#ab9917e933fd3a6676d393d13810fb63c&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">BitmapInfo.SetWidth()</a></span>, <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"BitmapInfo.SetHeight()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap_info.html#a2099e0a07f0102f9380c9337c649572f&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">BitmapInfo.SetHeight()</a></span>, <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"BitmapInfo.SetName()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap_info.html#ae7164557284c72a8f6da140cc32df8df&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">BitmapInfo.SetName()</a></span> methods and so forth to set properties on the bitmap.</p>\n\
<div class=\'codeBlock\'><pre>info = storage.GetBitmapInfo()    \n\
info.SetWidth(720)\n\
info.SetHeight(620)\n\
info.SetName(&#39;My demonstration bitmap&#39;)\n\
info.SetGamma(2.2)\n\
</pre></div><p>Call <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"BitmapStorage.Allocate()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap_storage.html#aaec9d7ff37dc97e29270d60b42d063fa&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">BitmapStorage.Allocate()</a></span> to allocate storage for writing to the bitmap.</p>\n\
<div class=\'codeBlock\'><pre>storage.Allocate(info, 2)\n\
</pre></div><p>To write the pixels, call <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"BitmapStorage.PutPixel()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap_storage.html#ad8db4d046e66ab47576b5770013ce74a&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">BitmapStorage.PutPixel()</a></span>:</p>\n\
<div class=\'codeBlock\'><pre>for x in range(720):\n\
    for y in range(620):\n\
        storage.PutPixel(x,y,(<a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Color64\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_color64.html&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">MaxPlus.Color64</a>(64000-(x*(64000/720)),(y*(64000/720)),64000,64000)))\n\
</pre></div><p>Finally, call <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"Bitmap.SetStorage()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap.html#a6dc72ca41fc73f08d8d1afb395725a6c&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">Bitmap.SetStorage()</a></span> and pass the <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"BitmapStorage\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap_storage.html&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">BitmapStorage</a></span> you created above as an argument.</p>\n\
<div class=\'codeBlock\'><pre>foo.SetStorage(storage)\n\
</pre></div><p>To display your bitmap, call <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"Bitmap.Display()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_bitmap.html#a564e33f3ffecb08b1f241c3ac6e97d3f&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">Bitmap.Display()</a></span>.</p>\n\
<blockquote>\n\
<p><strong>Note:</strong> <span class=\'code\'><a href=\"javascript:void(0)\" data-symbol=\"Factory.CreateBitmap()\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_factory.html#a07ee5f23ef113ffd43794d70546ba7c2&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../../&quot;}]\">Factory.CreateBitmap()</a></span> creates a bitmap instance that is never deleted, and therefore will always leak memory.</p>\n\
</blockquote>\n\
      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";