var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><script src=\"../scripts/lib/jquery-1.11.1.min.js\" type=\"text/javascript\"></script><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>pymxs API Introduction</title>\n\
   <meta name=\"topic-subtype\" content=\"Python\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style><script>$(document).ready(function() { yepnope.injectJs(\"./scripts/multireflink.js\"); });</script><script></script><div id=\"reflinkdiv\"></div>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>pymxs API Introduction</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"pymxs-api-introduction\"></a></div>\n\
<p>The <span class=\'code\'>pymxs</span> Python module provides a wrapper for the MAXScript engine, and exposes virtually all the interfaces, globals, and classes available in MAXScript.</p>\n\
<div class=\'section\'><a id=\"using-the-maxscript-runtime-in-python\"></a><h2 id=\"using-the-maxscript-runtime-in-python\">Using the MAXScript Runtime in Python</h2></div>\n\
<p>The <span class=\'code\'>pymxs</span> module exposes the MAXScript runtime, and all the global symbols it contains, to Python scripts. The runtime is dynamic, so global objects created in MAXScript are subsequently available to <span class=\'code\'>pymxs.runtime</span>.</p>\n\
<p>The names of objects available in the <span class=\'code\'>pymxs.runtime</span> module correspond to MAXScript globals. So, for example, to create a teapot you can use the MAXScript <span class=\'code\'>Teapot()</span> constructor like this:</p>\n\
<div class=\'codeBlock\'><pre>&gt;&gt;&gt; import pymxs\n\
&gt;&gt;&gt; rt = pymxs.runtime\n\
&gt;&gt;&gt; t = rt.Teapot()\n\
&gt;&gt;&gt; rt.classOf(t)\n\
&lt;GeometryClass&lt;Teapot&gt;&gt;\n\
<blockquote>\n\
</blockquote></pre></div><p><strong>Note:</strong> To print output in <span class=\'code\'>pymxs</span>, use the <span class=\'code\'>pymxs.print_()</span> function. This is provided because the &quot;print&quot; function in MAXScript conflicts with the Python print statement.</p>\n\
\n\
<div class=\'section\'><a id=\"maxscript-context-expressions\"></a><h2 id=\"maxscript-context-expressions\">MAXScript Context Expressions</h2></div>\n\
<p>The <span class=\'code\'>pymxs</span> module exposes MAXScript context expressions that can be used in conjunction with the Python <span class=\'code\'>with</span> statement. These expressions are:</p>\n\
<ul>\n\
<li><span class=\'code\'>pymxs.animate(True|False)</span></li>\n\
<li><span class=\'code\'>pymxs.attime(True|False)</span></li>\n\
<li><span class=\'code\'>pymxs.atlevel(True|False)</span></li>\n\
<li><span class=\'code\'>pymxs.quiet(True|False)</span></li>\n\
<li><span class=\'code\'>pymxs.redraw(True|False)</span></li>\n\
<li><span class=\'code\'>pymxs.undo(True|False)</span></li>\n\
<li><span class=\'code\'>pymxs.mxstoken()</span> - See &quot;Multi-Threading with MAXScript&quot; below.</li>\n\
</ul>\n\
<p>For example, to create a teapot and animate it:</p>\n\
<div class=\'codeBlock\'><pre>import pymxs\n\
at = pymxs.attime\n\
rt = pymxs.runtime\n\
t = rt.Teapot()\n\
\n\
with pymxs.animate(True):\n\
with at(1):\n\
    t.pos = rt.Point3(2,2,2)\n\
with at(12):\n\
    t.pos = rt.Point3(10, 10, 10)\n\
with at(21):\n\
    t.pos = rt.Point3(20,20,20)\n\
</pre></div><div class=\'section\'><a id=\"maxscript-undo-system\"></a><h2 id=\"maxscript-undo-system\">MAXScript Undo System</h2></div>\n\
<p>The undo system is exposed in <span class=\'code\'>pymxs</span> with:</p>\n\
<ul>\n\
<li><span class=\'code\'>pymxs.undo(True|False)</span></li>\n\
<li><span class=\'code\'>pymxs.run_undo()</span></li>\n\
<li><span class=\'code\'>pymxs.run_redo()</span></li>\n\
</ul>\n\
<p>As with MAXScript, operations run through pymxs are not recorded by the undo system. Undo must be specifically enabled. Undoable pymxs operations appear as items labeled <em>MAXScript</em> in the 3ds Max Undo menu.</p>\n\
<p>For example, to create a teapot, change its position, and then undo the change:</p>\n\
<div class=\'codeBlock\'><pre>import pymxs\n\
rt = pymxs.runtime\n\
# this will not be undoable:\n\
with pymxs.undo(False):\n\
    t = rt.Teapot()\n\
\n\
with pymxs.undo(True):\n\
    t.pos = rt.Point3(20,20,20)\n\
\n\
pymxs.run_undo() # undo the position\n\
pymxs.run_redo() # redo the position\n\
</pre></div><div class=\'section\'><a id=\"maxscript-type-marshalling\"></a><h2 id=\"maxscript-type-marshalling\">MAXScript Type Marshalling</h2></div>\n\
<p>For simple types such as integers, floats and strings, <span class=\'code\'>pymxs</span> has a direct reference to the data, and these values can be obtained and set directly.</p>\n\
<p>For complex types such as Array, pymxs wraps these objects with a <span class=\'code\'>MXSWrapper</span> object, <span class=\'code\'>pymxs.MXSWrapperBase</span>. For example:</p>\n\
<div class=\'codeBlock\'><pre>import pymxs\n\
rt = pymxs.runtime\n\
\n\
# Create and visit a MaxScript Array\n\
rt.execute(&quot; gma = #(1,2,3)&quot;)\n\
print rt.gma    #output: #(1,2,3)\n\
len(rt.gma)    #output: 3\n\
rt.gma[1] = 999\n\
rt.Print(rt.gma[1])    #output: 999\n\
l = list(rt.gma) #[1,999,3]\n\
l[2] = 888\n\
print l    #output: [1, 888, 3]\n\
print rt.gma   # output: #(1, 999, 3)\n\
\n\
# Create a MaxScript Array via python sequence\n\
ma = rt.Array(*(1, 2, 3))\n\
print ma    #output: #(1,2,3)\n\
</pre></div><p>For a complete demonstration of how to create, manipulate and cast complex MAXScript types in Python, see the <em>demoPyMXSTypeInterop.py</em> example.</p>\n\
<div class=\'section\'><a id=\"maxscript-names\"></a><h2 id=\"maxscript-names\">MAXScript Names</h2></div>\n\
<p>Name values in MAXScript can be referenced with pymxs.runtime.Name. For example, to use <span class=\'code\'>toolmode.coordsys world</span>:</p>\n\
<div class=\'codeBlock\'><pre>pymxs.runtime.toolMode.coordsys(pymxs.runtime.Name(&quot;world&quot;))\n\
</pre></div><div class=\'section\'><a id=\"multi-threading-with-maxscript\"></a><h2 id=\"multi-threading-with-maxscript\">Multi-threading With MAXScript</h2></div>\n\
<p>You cannot call <em>pymxs.runtime</em> commands directly on a worker thread, as this will cause a runtime exception. However, <em>pymxs</em> has a <span class=\'code\'>mxstoken()</span> function to support multi-threading by providing a synchronization mechanism between worker threads.</p>\n\
<p>For an example of this approach, see the example <span class=\"filePath\" translate=\"no\">&lt;maxdirectory&gt;\\scripts\\Python\\demoMXSToken.py</span>.</p>\n\
<div class=\'section\'><a id=\"by-reference-parameter-handling\"></a><h2 id=\"by-reference-parameter-handling\">By-Reference Parameter Handling</h2></div>\n\
<p>Values passed back to Python from pymxs MAXScript functions that take a by-reference parameter, can be translated to Python values using the <span class=\'code\'>pymxs.mxsreference()</span> function. Note that this is supported for types other than Python lists.</p>\n\
<p>For example:</p>\n\
<div class=\'codeBlock\'><pre class=\"prettyprint lang-py\">import MaxPlus\n\
rt = pymxs.runtime\n\
\n\
<a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Core.EvalMAXScript\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_core.html#a00c76297f347dd3d50c629827c7217a1&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../&quot;}]\">MaxPlus.Core.EvalMAXScript</a>(&quot;mySphere = sphere radius:10&quot;)\n\
<a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Core.EvalMAXScript\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_core.html#a00c76297f347dd3d50c629827c7217a1&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../&quot;}]\">MaxPlus.Core.EvalMAXScript</a>(&quot;myType = #reference&quot;)\n\
<a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Core.EvalMAXScript\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_core.html#a00c76297f347dd3d50c629827c7217a1&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../&quot;}]\">MaxPlus.Core.EvalMAXScript</a>(&quot;myResultArray = Array()&quot;)\n\
\n\
offset1 = rt.Point3(50.0, 50.0, 10.0)\n\
myReturnedList = []\n\
rt.maxOps.cloneNodes(rt.mySphere,  offset=offset1, cloneType=rt.myType, newNodes=pymxs.mxsreference(myReturnedList))\n\
print &quot;python array: &quot;\n\
print myReturnedList\n\
\n\
offset2 = rt.Point3(-50.0, -50.0, 10.0)\n\
rt.maxOps.cloneNodes(rt.mySphere,  offset=offset2, cloneType=rt.myType, newNodes=pymxs.mxsreference(rt.myResultArray))\n\
print &quot;runtime array: &quot;\n\
print rt.myResultArray\n\
\n\
</pre></div><p><strong>Note:</strong> for variables other than Python lists, the variable must be visible in the <span class=\'code\'>pymxs.runtime</span> context. For example, to pass a variable of type Color:</p>\n\
<div class=\'codeBlock\'><pre class=\"prettyprint lang-py\">import pymxs\n\
rt = pymxs.runtime\n\
<a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Core.EvalMAXScript\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_core.html#a00c76297f347dd3d50c629827c7217a1&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../&quot;}]\">MaxPlus.Core.EvalMAXScript</a>(&quot;myColor = color 100 10 10&quot;)\n\
print rt.myColor\n\
rt.maxOps.colorById(2,pymxs.mxsreference(rt.myColor))\n\
print rt.myColor\n\
</pre></div><p>Whereas, this approach will not work:</p>\n\
<div class=\'codeBlock\'><pre class=\"prettyprint lang-py\">import pymxs\n\
rt = pymxs.runtime\n\
myColor=rt.color(10,10,10)\n\
print myColor\n\
rt.maxOps.colorById(2,pymxs.mxsreference(myColor))\n\
print myColor\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";