var topic = "<!-- saved from url=(0024)http://docs.autodesk.com -->\n\
<html>\n\
   <head><script src=\"../scripts/lib/jquery-1.11.1.min.js\" type=\"text/javascript\"></script><meta http-equiv=\"Content-Type\" content=\"text/html; charset=utf-8\"><meta http-equiv=\"Content-Style-Type\" content=\"text/css\"><meta name=\"generator\" content=\"pandoc\"><meta http-equiv=\"Content-Type\" content=\"text/html; charset=UTF-8\"><script type=\"text/javascript\" src=\"../scripts/utils/adsk.redirect.js\"></script>\n\
      <title>Using PySide2</title>\n\
   <meta name=\"topic-subtype\" content=\"Python\"></head>\n\
   <body height=\"100%\"><div class=\"body_content\" id=\"body-content\"><style type=\"text/css\">code{white-space: pre;}</style><script>$(document).ready(function() { yepnope.injectJs(\"./scripts/multireflink.js\"); });</script><script></script><div id=\"reflinkdiv\"></div>\n\
      <div>\n\
         <div class=\"head\">\n\
            <h1>Using PySide2</h1>\n\
         </div>\n\
\n\
<div class=\'section\'><a id=\"using-pyside2\"></a></div>\n\
<p>Autodesk 3ds Max ships with a pre-built version of PySide 2.0 compatible with Python 2.7.6. This version includes all standard PySide modules.</p>\n\
<div class=\'section\'><a id=\"example-pyside-script\"></a><h2 id=\"example-pyside-script\">Example PySide Script</h2></div>\n\
<p>The following simple example shows how to obtain a handle for the PySide application object and create a widget:</p>\n\
<div class=\'codeBlock\'><pre class=\"prettyprint lang-py\">\n\
&#39;&#39;&#39;\n\
    Demonstrates how to create a QWidget with PySide2 and attach it to the 3dsmax main window.\n\
&#39;&#39;&#39;\n\
\n\
from PySide2 import QtCore\n\
from PySide2 import QtWidgets\n\
import MaxPlus\n\
\n\
def make_cylinder():\n\
    obj = <a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Factory.CreateGeomObject\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_factory.html#a3d630028591390310699de24f0a6a658&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../&quot;}]\">MaxPlus.Factory.CreateGeomObject</a>(MaxPlus.ClassIds.Cylinder)\n\
    obj.ParameterBlock.Radius.Value = 10.0\n\
    obj.ParameterBlock.Height.Value = 30.0\n\
    node = <a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Factory.CreateNode\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_factory.html#a5db9618585b8541c4f22a66190a3056f&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../&quot;}]\">MaxPlus.Factory.CreateNode</a>(obj)\n\
    time = <a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.Core.GetCurrentTime\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_core.html#a64e5daad3eabd66bdddb26ac04e31338&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../&quot;}]\">MaxPlus.Core.GetCurrentTime</a>()\n\
    <a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.ViewportManager.RedrawViews\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_viewport_manager.html#a7b577ec015706afcd0a150c3a0ef1938&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../&quot;}]\">MaxPlus.ViewportManager.RedrawViews</a>(time)\n\
    return\n\
\n\
def main():\n\
    <a href=\"javascript:void(0)\" data-symbol=\"MaxPlus.FileManager.Reset\" class=\"a_multireflink\" data-reflinkdata=\"[{&quot;path&quot;:&quot;py_ref/class_max_plus_1_1_file_manager.html#a0b0d7baf226241b1b81af09f3395962c&quot;,&quot;title&quot;:&quot;MaxPlus Python API Reference&quot;,&quot;relpathtoroot&quot;:&quot;../&quot;}]\">MaxPlus.FileManager.Reset</a>(True)\n\
\n\
    w = QtWidgets.QWidget(MaxPlus.GetQMaxMainWindow(), QtCore.Qt.Dialog)\n\
    _GCProtector.widgets.append(w)\n\
    w.resize(250, 100)\n\
    w.setWindowTitle(&#39;PySide Qt Window&#39;)\n\
\n\
    main_layout = QtWidgets.QVBoxLayout()\n\
    label = QtWidgets.QLabel(&quot;Click button to create a cylinder in the scene&quot;)\n\
    main_layout.addWidget(label)\n\
\n\
    cylinder_btn = QtWidgets.QPushButton(&quot;Cylinder&quot;)\n\
    cylinder_btn.clicked.connect(make_cylinder)\n\
    main_layout.addWidget(cylinder_btn)\n\
\n\
    textEdit = QtWidgets.QLineEdit()\n\
    textEdit.setText(&quot;Edit box&quot;)\n\
    main_layout.addWidget(textEdit)\n\
\n\
    w.setLayout(main_layout)\n\
    w.show()\n\
\n\
\n\
if __name__ == &#39;__main__&#39;:\n\
    main()\n\
\n\
</pre></div><p><em>Notes</em>:</p>\n\
<ul>\n\
<li>To make 3ds Max the parent of our QWidget, we create a new QWidget and pass it the main window handle returned by <span class=\'code\'>MaxPlus.GetQMaxMainWindow()</span>. To display the widget as modeless, call <span class=\'code\'>.show()</span>, and to open it as modal, call <span class=\'code\'>.exec_()</span>.</li>\n\
<li>To protect widgets from being garbage collected, you should keep references to them in a static class variable, such as the <span class=\'code\'>GCProtector.widgets</span> array in the example script.</li>\n\
<li>Nodes created within a script may not appear in Max until the script exits, unless you force a viewport update. You can do so with <span class=\'code\'>MaxPlus.ViewportManager.ForceCompleteRedraw()</span> or <span class=\'code\'>MaxPlus.ViewportManager.RedrawViews()</span>.</li>\n\
</ul>\n\
<div class=\'section\'><a id=\"loading-qt-ui-files\"></a><h2 id=\"loading-qt-ui-files\">Loading Qt UI Files</h2></div>\n\
<p>MaxPlus provides a facility for loading UI files created by Qt Designer: <span class=\'code\'>MaxPlus.LoadUiType()</span>. For example (from <em>demoPySideLoader.py</em>):</p>\n\
<div class=\'codeBlock\'><pre class=\"prettyprint lang-py\">import MaxPlus\n\
import os\n\
from PySide2.QtWidgets import QTabWidget\n\
\n\
class TestWidget(QTabWidget):\n\
    def __init__(self, ui_class, parent=None):\n\
        QTabWidget.__init__(self, parent)\n\
        self.ui= ui_class()\n\
        self.ui.setupUi(self)\n\
\n\
def test_load_ascii_ui_path(ui_path):\n\
    ui_class, base_class = MaxPlus.LoadUiType(ui_path)\n\
    instance = TestWidget(ui_class)\n\
    instance.show()\n\
    instance.close()\n\
\n\
def test_load_ui():\n\
    ui_path = os.path.join(os.path.dirname(__file__), &quot;test_ui.ui&quot;)\n\
    test_load_ascii_ui_path(ui_path)\n\
    # test unicode encoding\n\
    test_load_ascii_ui_path(u&#39;%s&#39; % ui_path)\n\
    # test a unicode encoding with non-ascii characters\n\
    try:\n\
        test_load_ascii_ui_path(u&#39;D:/你好&#39;)\n\
    except UnicodeEncodeError:\n\
        pass\n\
    else:\n\
        print &quot;Error: unexpected exception&quot;\n\
\n\
\n\
if __name__ == &quot;__main__&quot;:\n\
    test_load_ui()\n\
</pre></div>      <div class=\"footer-block\"><a href=\"../html/ac.cmtdialog.htm\" class=\"comments-anchor\" target=\"_blank\"><span class=\"comments-link\">Please send us your comment about this page</span></a></div></div>\n\
   </div></body>\n\
</html>\n\
";